import * as t from '@babel/types';
import { NodePath, Scope } from '@babel/traverse';

/**
 * Add id to function/class expression inferred from the AST
 *
 * @export
 * @template N The unnamed expression type
 * @param {Object} nodePathLike The NodePath-like input
 * @param {N} nodePathLike.node an AST node
 * @param {NodePath<N>["parent"]} [nodePathLike.parent] The parent of the AST node
 * @param {Scope} nodePathLike.scope The scope associated to the AST node
 * @param {t.LVal | t.StringLiteral | t.NumericLiteral | t.BigIntLiteral} [nodePathLike.id] the fallback naming source when the helper
 * can not infer the function name from the AST
 * @param {boolean} [localBinding=false] whether a name could shadow a self-reference (e.g. converting arrow function)
 * @param {boolean} [supportUnicodeId=false] whether the compilation target supports unicodeId (non-BMP characters) or not
 * @returns {(N | t.CallExpression | void)}
 * - modified node when name can be inferred,
 * - an IIFE when `node` contains a binding shadowing the inferred function name (e.g. `let f = function (f) {}`),
 * - `void` when `node` has `id` property or the helper can not inferred the name or the inferred name contains non-BMP characters that is not supported by current target
 */
declare function export_default<N extends t.FunctionExpression | t.Class>({ node, parent, scope, id, }: {
    node: N;
    parent?: NodePath<N>["parent"];
    scope: Scope;
    id?: t.AssignmentExpression["left"] | t.StringLiteral | t.NumericLiteral | t.BigIntLiteral;
}, localBinding?: boolean, supportUnicodeId?: boolean): N | t.CallExpression | void;

export { export_default as default };
